@@ -13,21 +13,16 @@ import shutil
 
 from textwrap import dedent
 
-from html2image.browsers import chrome, chrome_cdp#, firefox, firefox_cdp
-from html2image.browsers.browser import CDPBrowser
+from html2image.browsers import chrome, firefox
 
 browser_map = {
     'chrome': chrome.ChromeHeadless,
     'chromium': chrome.ChromeHeadless,
     'google-chrome': chrome.ChromeHeadless,
-
-    'chrome-cdp': chrome_cdp.ChromeCDP,
-    'chromium-cdp': chrome_cdp.ChromeCDP,
-
-    # 'firefox': firefox.FirefoxHeadless,
-    # 'mozilla-firefox': firefox.FirefoxHeadless,
-
-    # 'firefox-cdp': firefox_cdp.FirefoxCDP,
+    'googlechrome': chrome.ChromeHeadless,
+    'firefox': firefox.FirefoxHeadless,
+    'mozilla-firefox': firefox.FirefoxHeadless,
+    'mozilla firefox': firefox.FirefoxHeadless,
 }
 
 
@@ -70,12 +65,10 @@ class Html2Image():
         self,
         browser='chrome',
         browser_executable=None,
-        browser_cdp_port=None,
         output_path=os.getcwd(),
         size=(1920, 1080),
         temp_path=None,
         custom_flags=None,
-        disable_logging=False,
     ):
 
         if browser.lower() not in browser_map:
@@ -88,20 +81,10 @@ class Html2Image():
         self.temp_path = temp_path
 
         browser_class = browser_map[browser.lower()]
-
-        if isinstance(browser_class, CDPBrowser):
-            self.browser = browser_class(
-                executable=browser_executable,
-                flags=custom_flags,
-                cdp_port=browser_cdp_port,
-                disable_logging=disable_logging,
-            )
-        else:
-            self.browser = browser_class(
-                executable=browser_executable,
-                flags=custom_flags,
-                disable_logging=disable_logging,
-            )
+        self.browser = browser_class(
+            executable=browser_executable,
+            flags=custom_flags,
+        )
 
     @property
     def temp_path(self):
@@ -532,13 +515,6 @@ class Html2Image():
 
         return screenshot_paths
 
-    def __enter__(self):
-        self.browser.__enter__()
-        return self
-
-    def __exit__(self, *exc):
-        self.browser.__exit__(*exc)
-
 
 if __name__ == '__main__':
     pass
